from setuptools import setup

setup(name='ezprogbar',
    version='1.21',
    description='simple textual progress bar',
    url='http://github.com/samyzaf/ezprogbar',
    author='Samy Zafrany',
    author_email='admin@samyzaf.com',
    license='MIT',
    packages=['ezprogbar'],
    zip_safe=False,
)

